@@ -11,27 +11,28 @@
 /*     * netpipe.h          ---- General include file                        */
 /*****************************************************************************/
 
-/* $Id: netpipe.h,v 1.5 1998/09/24 15:18:46 ghelmer Exp $ */
+/* $Id: netpipe.h,v 1.7 1999/04/27 20:55:57 ghelmer Exp $ */
 
 #include <ctype.h>
 #include <errno.h>
 #include <signal.h>
 #include <stdio.h>
+#include <stdlib.h>         /* malloc(3) */
 #include <string.h>
 #include <sys/types.h>
 #include <sys/time.h>       /* struct timeval */
-#include <stdlib.h>         /* malloc(3) */
+#ifdef HAVE_GETRUSAGE
+#include <sys/resource.h>
+#endif
 
 
 #define  DEFPORT            5002
 #define  TRIALS             7
-#define  REPEAT             1000
 #define  NSAMP              8000
 #define  PERT               3
 #define  LATENCYREPS        100
 #define  LONGTIME           1e99
 #define  CHARSIZE           8
-#define  PATIENCE           50
 #define  RUNTM              0.25
 #define  STOPTM             1.0
 #define  MAXINT             2147483647
